@@ -1,6 +1,6 @@
 /* BlinkenLib
- * version 0.1.2 date 2008-08-10
- * Copyright (C) 2004-2006: Stefan Schuermans <1stein@schuermans.info>
+ * version 0.1.3 date 2008-09-29
+ * Copyright (C) 2004-2008: Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a blinkenarea.org project
  */
@@ -1130,6 +1130,9 @@ public class BlinkenMovie
       //open file
       file = new RandomAccessFile( filename, "rw" );
 
+      //truncate file
+     file.setLength( 0 );
+
       //write header
       header = new byte[24];
       header[0] = 0x23; //magic
